- full_model
Model fit using robumeta::robu(),
metafor::rma.mv(), or metafor::rma.uni() that includes the full set of moderators in the
meta-regression model.
- constraints
A q X p constraint matrix be tested. Alternately, a
function to create such a matrix, specified using
clubSandwich::constrain_equal() or
clubSandwich::constrain_zero().
- R
Number of bootstrap replications.
- cluster
Vector of identifiers indicating which observations
belong to the same cluster. If NULL (the default), then the
clustering variable will be inferred based on the structure of
full_mod.
- auxiliary_dist
Character string indicating the auxiliary distribution
to be used for cluster wild bootstrapping, with available options:
"Rademacher", "Mammen", "Webb six", "uniform", "standard normal". The
default is set to "Rademacher." We recommend the Rademacher distribution
for models that have at least 10 clusters. For models with less than 10
clusters, we recommend the use of "Webb six" distribution.
- adjust
Character string specifying which small-sample adjustment
should be used to multiply the residuals by. The available options are
"CRO", "CR1", "CR2", "CR3", or "CR4",
with a default of "CRO".
- type
Character string specifying which small-sample adjustment is used
to calculate the Wald test statistic. The available options are
"CRO", "CR1", "CR2", "CR3", or "CR4",
with a default of "CRO".
- test
Character string specifying which (if any) small-sample
adjustment is used in calculating the test statistic. Default is
"Naive-F", which does not make any small-sample adjustment.
- seed
Optional seed value to ensure reproducibility.
- future_args
Optional list of additional arguments passed to the
future_*() functions used in calculating results across bootstrap
replications. Ignored if the future.apply package is not available.